| Type: | Package |
| Title: | Processing and Transforming Relational Event History Data |
| Version: | 4.0.0 |
| Date: | 2026-04-30 |
| Maintainer: | Giuseppe Arena <g.arena@uva.nl> |
| Description: | Efficiently processes relational event history data and transforms them into formats suitable for other packages. The primary objective of this package is to convert event history data into a format that integrates with the packages in 'remverse' and is compatible with various analytical tools (e.g., computing network statistics, estimating tie-oriented or actor-oriented social network models). Second, it can also transform the data into formats compatible with other packages out of 'remverse'. The package processes the data for two types of temporal social network models: tie-oriented modeling framework (Butts, C., 2008, <doi:10.1111/j.1467-9531.2008.00203.x>) and actor-oriented modeling framework (Stadtfeld, C., & Block, P., 2017, <doi:10.15195/v4.a14>). |
| License: | MIT + file LICENSE |
| URL: | https://tilburgnetworkgroup.github.io/remify/ |
| BugReports: | https://github.com/TilburgNetworkGroup/remify/issues |
| Depends: | R (≥ 4.0.0) |
| Imports: | Rcpp (≥ 1.0.8.3), igraph (≥ 1.4.3) |
| Suggests: | knitr, rmarkdown, tinytest, remstats |
| LinkingTo: | Rcpp, RcppArmadillo, |
| VignetteBuilder: | knitr |
| Encoding: | UTF-8 |
| LazyData: | true |
| RoxygenNote: | 7.3.3 |
| LazyDataCompression: | gzip |
| NeedsCompilation: | yes |
| Packaged: | 2026-04-30 14:06:24 UTC; jorismulder |
| Author: | Giuseppe Arena |
| Repository: | CRAN |
| Date/Publication: | 2026-05-04 05:00:02 UTC |
remify: Processing and Transforming Relational Event History Data
Description
Efficiently processes relational event history data and transforms them into formats suitable for other packages. The primary objective of this package is to convert event history data into a format that integrates with the packages in 'remverse' and is compatible with various analytical tools (e.g., computing network statistics, estimating tie-oriented or actor-oriented social network models). Second, it can also transform the data into formats compatible with other packages out of 'remverse'. The package processes the data for two types of temporal social network models: tie-oriented modeling framework (Butts, C., 2008, doi:10.1111/j.1467-9531.2008.00203.x) and actor-oriented modeling framework (Stadtfeld, C., & Block, P., 2017, doi:10.15195/v4.a14).
Author(s)
Maintainer: Giuseppe Arena g.arena@uva.nl (ORCID)
Authors:
Joris Mulder j.mulder3@tilburguniversity.edu
Other contributors:
Rumana Lakdawala [contributor]
Marlyne Meijerink-Bosman [contributor]
Diana Karimova [contributor]
Fabio Generoso Vieira [contributor]
Mahdi Shafiee Kamalabad [contributor]
Roger Leenders r.t.a.j.leenders@tilburguniversity.edu [contributor]
See Also
Useful links:
Report bugs at https://github.com/TilburgNetworkGroup/remify/issues
dim.remify
Description
A function that returns the dimension of the temporal network.
Usage
## S3 method for class 'remify'
dim(x)
Arguments
x |
a |
Value
vector of dimensions of the processed event sequence.
Examples
# processing the random network 'randomREHsmall'
library(remify)
data(randomREHsmall)
reh <- remify(edgelist = randomREHsmall$edgelist,
model = "tie")
# dimensions of the processed 'remify' object
dim(reh)
History dataset
Description
A relational event history dataset for testing and examples.
Usage
history
Format
A data frame that can be used for an analysis with remify, remstats, remstimate
remstats package
plot.remify
Description
several plots that describe the network of relational events, both for directed and undirected relational events.
Usage
## S3 method for class 'remify'
plot(
x,
which = c(1:5),
breaks = 15L,
palette = "Purples",
n_intervals = 4L,
rev = TRUE,
actors = NULL,
pch.degree = 20,
igraph.edge.color = "#4daa89",
igraph.vertex.color = "#5AAFC8",
...
)
Arguments
x |
is a |
which |
one or more numbers between 1 and 5. Plots described in order: (1) distribution of the inter-event times (histogram), (2) tile plot titled 'activity plot', with in-degree and out-degree activity line plots on the sides (or total-degree on the top side if the network is undirected). Tiles' color is scaled based on the count of the directed (or undirected) dyad, (3) for directed networks two plots of normalized out-degree and in-degree (values ranging in [0,1]) over a set of |
breaks |
default is |
palette |
a palette from |
n_intervals |
number of time intervals for time plots (default is |
rev |
default is TRUE (reverse order of the color specified in |
actors |
default is the set of actors in the network (see |
pch.degree |
default is 20. Shape of the points for the degree plots (in-degree, out-degree, total-degree). |
igraph.edge.color |
color of the edges in visualization of the network with vertices and nodes. The user can specify the hex value of a color, the color name or use the function |
igraph.vertex.color |
color of the vertices in visualization of the network with vertices and nodes. The user can specify the hex value of a color, the color name or use the function |
... |
other graphical parameters |
Details
Generic plot method
Value
no return value, called for plotting descriptives on the relational event history data.
print.remify
Description
print a summary of the event history.
Usage
## S3 method for class 'remify'
print(x, ...)
Arguments
x |
a |
... |
further arguments. |
Value
displays the same information provided by the summary method.
Examples
# processing the random network 'randomREHsmall'
library(remify)
data(randomREHsmall)
reh <- remify(edgelist = randomREHsmall$edgelist,
model = "tie")
# printing a summary of the processed 'remify' object
print(reh)
Random Relational Event History
Description
A randomly generated sequence of relational events with 20 actors and 9915 events. Each event type is associated to one of the three following sentiments: conflict, competition and cooperation.
Usage
randomREH
Format
data(randomREH) will load a list containing following objects:
edgelista
data.framethat contains the random sequence of events. Columns of the edgelist are:timethe timestamp indicating the time at which each event occurred;
actor1the name of the actor that generated the relational event;
actor2the name of the actor that received the relational event;
typethe type of the relational event.
actorsnames of actors interacting in the dynamic network.
typesnames of event types observed in the network and describing the sentiment of the interaction (conflict, competition and cooperation).
originstarting time point (
t_0) prior to the first observed event (t_1), the class of this object must be the same as the one of the time column in the edgelist.omit_dyada list where each element describes an alteration of the riskset which takes place at specific time points and for certain actors and/or types.
Examples
data(randomREH)
# actors names
randomREH$actors
# types names
randomREH$types
# run the preprocessing function reh() by supplying the loaded objects.
edgelist_reh <- remify(edgelist = randomREH$edgelist,
actors = randomREH$actors,
directed = TRUE,
ordinal = FALSE,
origin = randomREH$origin,
model = "tie")
# `edgelist_reh` is an object of class `remify`
class(edgelist_reh)
# names of objects inside `edgelist_reh`
names(edgelist_reh)
Random Relational Event History (small)
Description
A subset from the randomly generated sequence of relational events 'randomREH', with 5 actors and 586 events (without event types).
Usage
randomREHsmall
Format
data(randomREHsmall) will load a list containing following objects:
edgelista
data.framethat contains the random sequence of events. Columns of the edgelist are:timethe timestamp indicating the time at which each event occurred;
actor1the name of the actor that generated the relational event;
actor2the name of the actor that received the relational event;
actorsnames of actors interacting in the dynamic network.
originstarting time point (
t_0) prior to the first observed event (t_1), the class of this object must be the same as the one of the time column in the edgelist.omit_dyada list where each element describes an alteration of the riskset which takes place at specific time points and for certain actors and/or types.
Examples
data(randomREHsmall)
# actors names
randomREHsmall$actors
# types names
randomREHsmall$types
# run the preprocessing function reh() by supplying the loaded objects.
small_edgelist_reh <- remify(edgelist = randomREHsmall$edgelist,
actors = randomREHsmall$actors,
directed = TRUE,
ordinal = FALSE,
origin = randomREHsmall$origin,
model = "tie")
# `small_edgelist_reh` is an object of class `reh`
class(small_edgelist_reh)
# names of objects inside `small_edgelist_reh`
names(small_edgelist_reh)
Process a Relational Event History
Description
A function that processes raw relational event history data and returns a S3 object of class 'remify' which is used as input in other functions inside 'remverse'.
Usage
remify(
edgelist,
directed = TRUE,
ordinal = FALSE,
model = c("tie", "actor"),
thin = 1,
actors = NULL,
riskset = c("full", "active", "active_saturated", "manual"),
manual.riskset = NULL,
extend_riskset_by_type = FALSE,
event_type = NULL,
origin = NULL,
time.units = c("auto", "secs", "mins", "hours", "days", "weeks"),
attach_riskset = TRUE,
riskset_decode = c("labels", "ids", "none"),
riskset_max_decode = 200000L,
event_covariates = NULL,
ncores = 1L,
omit_dyad = NULL
)
Arguments
edgelist |
the relational event history. An object of class |
directed |
logical value indicating whether events are directed ( |
ordinal |
logical value indicating whether only the order of events matters in the model ( |
model |
either |
thin |
Integer >= 1. Event-time thinning based on unique time points.
Keeps every |
actors |
[optional] character vector of actors' names that may be observed interacting in the network. If |
riskset |
[optional] character value indicating the type of risk set to process: |
manual.riskset |
[optional] When |
extend_riskset_by_type |
logical. |
event_type |
Optional. Either If If When event types are present (via |
origin |
[optional] starting time point of the observation period (default is |
time.units |
Character string specifying the time unit for converting time values when 'edgelist$time' is of class Date or POSIXct; ignored for numeric or integer time. Default is "secs". |
attach_riskset |
Logical. If |
riskset_decode |
Character. Controls how (and whether) the included risk set
dyads are decoded and attached in
|
riskset_max_decode |
Integer. Maximum number of included dyads (i.e.,
|
event_covariates |
Optional character vector of column names in
These columns are stored as Note: |
ncores |
[optional] number of cores used in the parallelization of the processing functions. (default is |
omit_dyad |
Deprecated. Set to |
Details
In omit_dyad, the NA value can be used to remove multiple objects from the risk set at once with one risk set modification list. For example, to remove all events with sender equal to actor “A” add a list with two objects time = c(NA, NA) and dyad = data.frame(actor1 = A, actor2 = NA, type = NA) to the omit_dyad list. For more details about
Value
A remify S3 object (list) with the following elements:
-
Mnumber of events (or unique time points if simultaneous events exist). -
Nnumber of actors. -
Cnumber of event types (1 if untyped). -
Dnumber of dyads in the riskset. -
intereventTimevector of inter-event waiting times (NULLifordinal=TRUE). -
edgelistprocessed input edgelist asdata.frame. -
edgelist_idper-event integer ID summary. -
metalist of metadata (model, directed, ordinal, riskset, dictionary, etc.). -
idslist of per-event integer IDs (actor1, actor2, dyad, type). -
indexlist of decoded riskset tables (dyad_mapordyad_map_activefor tie model;sender_mapfor actor model). -
activeDnumber of active dyads (tie model,riskset="active"or"manual"only). -
riskset_infodecoded riskset metadata (tie model only, whenattach_riskset=TRUE).
For actor-oriented models (model="actor"), the following additional elements are returned:
-
sender_risksetinteger vector of actor IDs allowed to send (all actors for"full"; observed senders for"active"; senders inmanual.risksetfor"manual"/"active_saturated"). -
receiver_risksetnamed list (actor names) of integer vectors of allowed receiver IDs per sender. -
activeNnumber of active senders. -
index\$sender_mapdata.frame with columnssenderIDandactorNamefor active senders.
Examples
# load package and random network 'randomREH'
library(remify)
data(randomREH)
# first events in the sequence
head(randomREH$edgelist)
# actor's names
randomREH$actors
# event type's names
randomREH$types
# start time of the study (origin)
randomREH$origin
# list of changes of the risk set: each one is a list of:
# 'time' (indicating the time window where to apply the risk set reduction)
# 'dyad' (a data.frame describing the dyads to remove from the risk set
# during the time window specified in 'time')
str(randomREH$omit_dyad)
# -------------------------------------- #
# processing for tie-oriented modeling #
# -------------------------------------- #
tie_randomREH <- remify(edgelist = randomREH$edgelist,
directed = TRUE,
ordinal = FALSE,
model = "tie",
origin = randomREH$origin)
# summary
summary(tie_randomREH)
# visualize descriptive measures of relational event data
plot(x = tie_randomREH)
# -------------------------------------- #
# processing for actor-oriented modeling #
# -------------------------------------- #
# loading network 'randomREHsmall'
data(randomREHsmall)
# processing small random network
actor_randomREH <- remify(edgelist = randomREHsmall$edgelist,
directed = TRUE,
ordinal = FALSE,
model = "actor",
actors = randomREHsmall$actors,
origin = randomREHsmall$origin)
# summary
summary(actor_randomREH)
# visualize
plot(actor_randomREH)
# ------------------------------------ #
# for more information about remify() #
# check: vignette(package="remify") #
# ------------------------------------ #
summary.remify
Description
A function that returns a easy-to-read summary of the main characteristics as to the processed relational event sequence.
Usage
## S3 method for class 'remify'
summary(object, ...)
Arguments
object |
a |
... |
other arguments. |
Value
prints out the main characteristics of the processed relational event sequence.
Examples
# processing the random network 'randomREHsmall'
library(remify)
data(randomREHsmall)
reh <- remify(edgelist = randomREHsmall$edgelist,
model = "tie")
# printing a summary of the processed 'remify' object
summary(reh)